@@ -21,8 +21,10 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     ExperimentResultRequestTypeType,
+    ExperimentStatusType,
     ExperimentStopDesiredStateType,
     FeatureEvaluationStrategyType,
+    LaunchStatusType,
     LaunchStopDesiredStateType,
 )
 from .paginator import (
@@ -320,7 +322,12 @@ class CloudWatchEvidentlyClient(BaseClient):
         """
 
     def list_experiments(
-        self, *, project: str, maxResults: int = ..., nextToken: str = ...
+        self,
+        *,
+        project: str,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        status: ExperimentStatusType = ...
     ) -> ListExperimentsResponseTypeDef:
         """
         Returns configuration details about all the experiments in the specified
@@ -341,7 +348,12 @@ class CloudWatchEvidentlyClient(BaseClient):
         """
 
     def list_launches(
-        self, *, project: str, maxResults: int = ..., nextToken: str = ...
+        self,
+        *,
+        project: str,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        status: LaunchStatusType = ...
     ) -> ListLaunchesResponseTypeDef:
         """
         Returns configuration details about all the launches in the specified project.
