@@ -30,6 +30,7 @@ from typing import Generic, Iterator, TypeVar
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
+from .literals import ExperimentStatusType, LaunchStatusType
 from .type_defs import (
     ListExperimentsResponseTypeDef,
     ListFeaturesResponseTypeDef,
@@ -63,7 +64,11 @@ class ListExperimentsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, project: str, PaginationConfig: PaginatorConfigTypeDef = ...
+        self,
+        *,
+        project: str,
+        status: ExperimentStatusType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListExperimentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListExperiments.paginate)
@@ -93,7 +98,11 @@ class ListLaunchesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, project: str, PaginationConfig: PaginatorConfigTypeDef = ...
+        self,
+        *,
+        project: str,
+        status: LaunchStatusType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListLaunchesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/evidently.html#CloudWatchEvidently.Paginator.ListLaunches.paginate)
