@@ -781,6 +781,7 @@ _OptionalListExperimentsRequestRequestTypeDef = TypedDict(
     {
         "maxResults": int,
         "nextToken": str,
+        "status": ExperimentStatusType,
     },
     total=False,
 )
@@ -843,6 +844,7 @@ _OptionalListLaunchesRequestRequestTypeDef = TypedDict(
     {
         "maxResults": int,
         "nextToken": str,
+        "status": LaunchStatusType,
     },
     total=False,
 )
@@ -896,18 +898,30 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-MetricDefinitionConfigTypeDef = TypedDict(
-    "MetricDefinitionConfigTypeDef",
+_RequiredMetricDefinitionConfigTypeDef = TypedDict(
+    "_RequiredMetricDefinitionConfigTypeDef",
     {
         "entityIdKey": str,
-        "eventPattern": str,
         "name": str,
-        "unitLabel": str,
         "valueKey": str,
     },
+)
+_OptionalMetricDefinitionConfigTypeDef = TypedDict(
+    "_OptionalMetricDefinitionConfigTypeDef",
+    {
+        "eventPattern": str,
+        "unitLabel": str,
+    },
     total=False,
 )
 
+
+class MetricDefinitionConfigTypeDef(
+    _RequiredMetricDefinitionConfigTypeDef, _OptionalMetricDefinitionConfigTypeDef
+):
+    pass
+
+
 MetricDefinitionTypeDef = TypedDict(
     "MetricDefinitionTypeDef",
     {
